===========
livemetrics
===========

.. image:: https://readthedocs.org/projects/livemetrics/badge/?version=latest
    :target: https://livemetrics.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. image:: https://img.shields.io/pypi/l/livemetrics.svg
    :target: https://pypi.org/project/livemetrics/
    :alt: CeCILL-C

.. image:: https://img.shields.io/pypi/v/livemetrics.svg
    :target: https://pypi.org/project/livemetrics/
    :alt: v?.?

.. image:: https://img.shields.io/pypi/pyversions/livemetrics.svg
    :target: https://pypi.org/project/livemetrics/
    :alt: Python 3.x

.. image:: https://travis-ci.org/idemia/python-livemetrics.svg?branch=master
    :target: https://travis-ci.org/idemia/python-livemetrics
    :alt: Build Status (Travis CI)

.. image:: https://codecov.io/gh/idemia/python-livemetrics/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/idemia/python-livemetrics
    :alt: Code Coverage Status (Codecov)

A Python library for building and publishing live business metrics used to have insights
about the behavior of applications.

It is based on the Dropwizard `metrics <https://metrics.dropwizard.io/>`_ library for Java.

Installation
============

``livemetrics`` is published on PyPI and can be installed from there::

    pip install -U livemetrics

Quick Start
===========


See `the full documentation <http://livemetrics.readthedocs.io/>`_ for more details.


